@@ -521,8 +521,8 @@ def determine_sn_rate(
     sdssArea = 5713.
     sdssSFRupperRedshiftLimit = 0.033
     sdssSFR = 14787.21
-    CCSNRateFraction = 0.007
-    transientToCCSNRateFraction = 1./10000.
+    # CCSNRateFraction = 0.007
+    # transientToCCSNRateFraction = 1./10000.
     transientRateFraction = CCSNRateFraction*transientToCCSNRateFraction
 
     anchor = redshiftResolution/sdssSFRupperRedshiftLimit
